@@ -647,9 +647,6 @@ class FeatureGenerator:
                                              output_file=None)
 
         # Normalize column names
-        mapping_df.columns = mapping_df.columns.str.strip().str.capitalize()
-        sector_df.columns = sector_df.columns.str.strip().str.capitalize()
-        df.columns = df.columns.str.strip().str.capitalize()
 
         # Merge mapping
         df = df.merge(mapping_df, on=ticker_column_name, how="left")
@@ -663,23 +660,25 @@ class FeatureGenerator:
         # Sort for rolling ops
         df = df.sort_values([ticker_column_name, datetime_column_name])
         # ---- RETURN SPREADS ----
+        print(df)
+        print(df.columns)
         for w in windows:
             # Cumulative returns over horizon w
             df[f"Company_CumRet_{w}D"] = (
-                    1 + df.groupby("Symbol")[returns_column_name].transform(lambda x: x.rolling(w).sum())
+                    1 + df.groupby(ticker_column_name)[returns_column_name].transform(lambda x: x.rolling(w).sum())
             )
             df[f"Sector_CumRet_{w}D"] = (
-                    1 + df.groupby("Sector")["Sector_Return"].transform(lambda x: x.rolling(w).sum())
+                    1 + df.groupby(sector_column_name)["Median_Return"].transform(lambda x: x.rolling(w).sum())
             )
             df[f"Return_Spread_{w}D"] = df[f"Company_CumRet_{w}D"] - df[f"Sector_CumRet_{w}D"]
 
         # ---- VOLATILITY SPREADS ----
         for w in windows:
             df[f"Company_Vol_{w}D"] = (
-                df.groupby("Symbol")[returns_column_name].transform(lambda x: x.rolling(w).std())
+                df.groupby(ticker_column_name)[returns_column_name].transform(lambda x: x.rolling(w).std())
             )
             df[f"Sector_Vol_{w}D"] = (
-                df.groupby("Sector")["Sector_Return"].transform(lambda x: x.rolling(w).std())
+                df.groupby(sector_column_name)["Median_Return"].transform(lambda x: x.rolling(w).std())
             )
             df[f"Vol_Spread_{w}D"] = df[f"Company_Vol_{w}D"] - df[f"Sector_Vol_{w}D"]
 
