@@ -1968,14 +1968,11 @@ def _compute_daily_sector_median_returns(mapping_df, returns_df,
     """
 
     # Load the mapping and returns
-
     # Ensure correct column naming
-    mapping_df = mapping_df.rename(columns=lambda x: x.strip().capitalize())
-    returns_df = returns_df.rename(columns=lambda x: x.strip().capitalize())
 
     # Merge returns with sector mapping
-    merged_df = returns_df.merge(mapping_df, on=ticker_column_name, how="left")
 
+    merged_df = returns_df.merge(mapping_df, on=ticker_column_name, how="left")
     # Group by Date + Sector and compute median
     sector_median = (
         merged_df
